

|Image1Link|_ |Image2Link|_ |Image3Link|_ |Image4Link|_

.. |Image1Link| image:: https://img.shields.io/travis/sonofeft/EngCoolProp.svg
.. _Image1Link: https://travis-ci.org/sonofeft/EngCoolProp

.. |Image2Link| image:: https://img.shields.io/pypi/v/EngCoolProp.svg
.. _Image2Link: https://pypi.python.org/pypi/engcoolprop

.. |Image3Link| image:: https://img.shields.io/pypi/pyversions/EngCoolProp.svg
.. _Image3Link: https://wiki.python.org/moin/Python2orPython3

.. |Image4Link| image:: https://img.shields.io/pypi/l/EngCoolProp.svg
.. _Image4Link: https://pypi.python.org/pypi/engcoolprop

